@@ -1,5 +1,5 @@
 package Acme::CPANAuthors::DualLife;
-$Acme::CPANAuthors::DualLife::VERSION = '0.38';
+$Acme::CPANAuthors::DualLife::VERSION = '0.40';
 #ABSTRACT: We are CPAN Authors of Dual Life core modules
 
 use strict;
@@ -19,6 +19,7 @@ use Acme::CPANAuthors::Register (
   DAPM => q[David A P Mitchell],
   DROLSKY => q[Dave Rolsky],
   DWHEELER => q[David E. Wheeler],
+  ESAYM => q[Samuel Smith],
   ETHER => q[Karen Etheridge],
   EXODIST => q[Chad Granum],
   FERREIRA => q[Adriano Ferreira],
@@ -26,7 +27,6 @@ use Acme::CPANAuthors::Register (
   GAAS => q[Gisle Aas],
   GBARR => q[Graham Barr],
   HMBRAND => q[H.Merijn Brand],
-  ILYAZ => q[Ilya Zakharevich],
   JDB => q[Jan Dubois],
   JDHEDDEN => q[Jerry D. Hedden],
   JESSE => q[Jesse Vincent],
@@ -34,11 +34,13 @@ use Acme::CPANAuthors::Register (
   JSTOWE => q[Jonathan Stowe],
   JV => q[Johan Vromans],
   KANE => q[Jos Boumans],
+  KHW => q[Karl Williamson],
   LEEJO => q[Lee Johnson],
   LEONT => q[Leon Timmermans],
   LLAP => q[Leo Lapworth],
   MAKAMAKA => q[Makamaka Hannyaharamitu],
   MALLEN => q[Mark Allen],
+  MARCGREEN => q[Marc Green],
   MAREKR => q[Marek Rouchal],
   MHX => q[Marcus Holland-Moritz],
   MJD => q[Mark Jason Dominus],
@@ -88,7 +90,7 @@ Acme::CPANAuthors::DualLife - We are CPAN Authors of Dual Life core modules
 
 =head1 VERSION
 
-version 0.38
+version 0.40
 
 =head1 SYNOPSIS
 
@@ -124,6 +126,7 @@ It is currently statically generated information, I hope to make it dynamic in t
   DAPM => q[David A P Mitchell],
   DROLSKY => q[Dave Rolsky],
   DWHEELER => q[David E. Wheeler],
+  ESAYM => q[Samuel Smith],
   ETHER => q[Karen Etheridge],
   EXODIST => q[Chad Granum],
   FERREIRA => q[Adriano Ferreira],
@@ -131,7 +134,6 @@ It is currently statically generated information, I hope to make it dynamic in t
   GAAS => q[Gisle Aas],
   GBARR => q[Graham Barr],
   HMBRAND => q[H.Merijn Brand],
-  ILYAZ => q[Ilya Zakharevich],
   JDB => q[Jan Dubois],
   JDHEDDEN => q[Jerry D. Hedden],
   JESSE => q[Jesse Vincent],
@@ -139,11 +141,13 @@ It is currently statically generated information, I hope to make it dynamic in t
   JSTOWE => q[Jonathan Stowe],
   JV => q[Johan Vromans],
   KANE => q[Jos Boumans],
+  KHW => q[Karl Williamson],
   LEEJO => q[Lee Johnson],
   LEONT => q[Leon Timmermans],
   LLAP => q[Leo Lapworth],
   MAKAMAKA => q[Makamaka Hannyaharamitu],
   MALLEN => q[Mark Allen],
+  MARCGREEN => q[Marc Green],
   MAREKR => q[Marek Rouchal],
   MHX => q[Marcus Holland-Moritz],
   MJD => q[Mark Jason Dominus],
